@@ -1,16 +1,17 @@
 '''
 python-lambda-local: Main module
 
-Copyright 2015 HDE, Inc.
+Copyright 2015-2017 HDE, Inc.
 Licensed under MIT.
 '''
 
 from __future__ import print_function
 import argparse
-from main import run
 import sys
 from multiprocessing import Process
 
+from .main import run
+
 
 def main():
     args = parse_args()
@@ -46,5 +47,6 @@ Default: 3")
 
     return parser.parse_args()
 
+
 if __name__ == "__main__":
     main()
